require "agent_smith/version"
require "thor"
require "openssl"
require 'open-uri'
require 'plist'

PROVISIONING_PATH = "#{Dir.home}/Library/MobileDevice/Provisioning Profiles/"
APPLE_ROOT_CERTIFICATE_URL = 'http://www.apple.com/appleca/AppleIncRootCertificate.cer'

module AgentSmith
 	class CLI < ::Thor

		desc "delete_all", "delete all the provisioning profiles installed."
		def delete_all
			prov_profiles = Dir["#{PROVISIONING_PATH}/*.mobileprovision"]
			prov_profiles.each do |file|
				system "rm \"#{file}\""
				puts "#{File.basename(file)} removed"
			end
			puts "done"
		end

		desc "install", "install provisioning profiles from a repository"
		long_desc <<-LONGDESC
    		
`agent_smith install --repo=git@github.com:Organization/provisioning-profiles` 
will execute `agent_smith delete_all` and then will install all the provisioning
profiles present in the given repository.
 
LONGDESC

		option :repo, :required => true
		option :temp_dir

		def install

			delete_all

			Dir.chdir (options[:temp_dir] || Dir.mktmpdir) do
				
				system "mkdir -p #{PROVISIONING_PATH.gsub(" ","\\ ")}"
				system "git clone #{options[:repo]} repo &> /dev/null"
				certificate = open(APPLE_ROOT_CERTIFICATE_URL).read()

				prov_profiles = Dir["repo/**/**.mobileprovision"]
				puts "#{prov_profiles.count} provisioning profiles found"

				prov_profiles.each do |prov_profile|
		

					prov_profile_content = File.read(prov_profile)
					p7 = OpenSSL::PKCS7.new(prov_profile_content)
					store = OpenSSL::X509::Store.new
					
					cert = OpenSSL::X509::Certificate.new(certificate)
					store.add_cert(cert)
					verification = p7.verify([cert], store)


					if verification
						plist = Plist::parse_xml(p7.data)
						uuid = plist["UUID"]
						system "cp #{prov_profile} #{PROVISIONING_PATH.gsub(" ","\\ ")}#{uuid}.mobileprovision"
						puts "#{File.basename(prov_profile)} installed"
					else
						puts "#{File.basename(prov_profile)} is not valid"
					end

				end
			end

		end

	end
end
